@@ -57,7 +57,7 @@ class Client(Headers):
 			"student_id": self.student.student_id
 		})
 
-		response = await helpers.post(f"{self.api}/schedule/diary", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
+		response = objects.Timetable(await helpers.post(f"{self.api}/schedule/diary", headers=self.headers(data=data, access_token=self.student.access_token), data=data))
 		return response
 
 	async def get_student_performance(self, start_date: str = None, end_date: str = None):
@@ -73,7 +73,7 @@ class Client(Headers):
 			"student_id": self.student.student_id
 		})
 
-		response = await helpers.post(f"{self.api}/schedule/student-performance", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
+		response = objects.StudentPerformance(await helpers.post(f"{self.api}/schedule/student-performance", headers=self.headers(data=data, access_token=self.student.access_token), data=data))
 		return response
 
 
@@ -91,7 +91,7 @@ class Client(Headers):
 			"subject_id": subject_id
 		})
 
-		response = await helpers.post(f"{self.api}/schedule/subject-grades", headers=self.headers(data=data, access_token=self.student.access_token), data=data)
+		response = LessonPerformance(await helpers.post(f"{self.api}/schedule/subject-grades", headers=self.headers(data=data, access_token=self.student.access_token), data=data))
 		return response
 
 
